@@ -1,10 +1,12 @@
 from html.parser import HTMLParser
 import pathlib
-class ImageParser(HTMLParser):
+
+class TagWithSourceParser(HTMLParser):
   def __init__(self,*args,**kwargs):
     super().__init__(*args,**kwargs)
-    self.images = list()
+    self.sources = list()
 
   def handle_starttag(self, tag, attrs):
-      if tag=="img":
-          self.images.append(pathlib.Path(dict(attrs)["src"]))
+    attrs = dict(attrs)
+    if 'src' in attrs:
+      self.sources.append(pathlib.Path(attrs["src"]))
